==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/features/profiles/gui/ProfilesScreen.java <==
package net.inventive_mods.inventive_inventory.features.profiles.gui;

import com.mojang.blaze3d.systems.RenderSystem;
import net.minecraft.class_1703;
import net.minecraft.class_2561;
import net.minecraft.class_286;
import net.minecraft.class_287;
import net.minecraft.class_289;
import net.minecraft.class_290;
import net.minecraft.class_293;
import net.minecraft.class_332;
import net.minecraft.class_3675;
import net.minecraft.class_465;
import net.minecraft.class_757;
import net.minecraft.client.render.*;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.inventive_mods.inventive_inventory.features.profiles.Profile;
import net.inventive_mods.inventive_inventory.features.profiles.ProfileHandler;
import net.inventive_mods.inventive_inventory.features.profiles.gui.widgets.Section;
import net.inventive_mods.inventive_inventory.keys.KeyRegistry;
import net.inventive_mods.inventive_inventory.util.mouse.MouseLocation;

import java.util.ArrayList;
import java.util.List;

public class ProfilesScreen extends class_465<class_1703> {
    public static final int RADIUS = 60;
    public static final int COLOR = 0x7F000000;
    public static final int HOVER_COLOR = 0x3FFFFFFF;
    public static final int DELETE_COLOR = 0x7FE4080A;
    public static final int OVERWRITE_COLOR = 0x7FFFDE59;
    private static final List<Section> sections = new ArrayList<>();
    public static boolean DELETE_KEY_PRESSED;
    public static boolean OVERWRITE_KEY_PRESSED;
    private int mouseX;
    private int mouseY;

    public ProfilesScreen() {
        super(InventiveInventory.getScreenHandler(), InventiveInventory.getPlayer().method_31548(), class_2561.method_43470("Profile Screen"));
        if (this.field_22787 != null) this.field_22787.method_18502(null);
        sections.clear();
        for (Profile profile : ProfileHandler.getProfiles()) {
            if (sections.size() <= ProfileHandler.MAX_PROFILES) sections.add(new Section(sections.size(), profile));
        }
        if (sections.size() < ProfileHandler.MAX_PROFILES) sections.add(new Section(sections.size(), null));
        DELETE_KEY_PRESSED = false;
        OVERWRITE_KEY_PRESSED = false;
    }

    public static List<Section> getSections() {
        return sections;
    }

    @Override
    protected void method_2389(class_332 context, float delta, int mouseX, int mouseY) {
    }

    @Override
    public void method_25394(class_332 context, int mouseX, int mouseY, float delta) {
        this.mouseX = mouseX;
        this.mouseY = mouseY;

        RenderSystem.enableBlend();
        RenderSystem.setShader(class_757::method_34540);
        RenderSystem.setShaderColor(1.0F, 1.0F, 1.0F, 1.0F);

        class_287 builder = class_289.method_1348().method_1349();
        builder.method_1328(class_293.class_5596.field_27382, class_290.field_1576);

        for (Section section : sections) {
            section.drawBackground(builder, section.isHovered(mouseX, mouseY));
        }
        class_286.method_43433(builder.method_1326());

        for (Section section : sections) {
            section.drawIcon(context);
            section.drawTooltips(context, mouseX, mouseY);
        }
        RenderSystem.disableBlend();
    }

    @Override
    public boolean method_25404(int keyCode, int scanCode, int modifiers) {
        if (class_3675.field_31949 == keyCode) {
            DELETE_KEY_PRESSED = true;
            return true;
        } else if (class_3675.field_31950 == keyCode) {
            OVERWRITE_KEY_PRESSED = true;
            return true;
        }
        return false;
    }

    @Override
    public boolean method_16803(int keyCode, int scanCode, int modifiers) {
        if (KeyRegistry.openProfilesScreenKey.method_1417(keyCode, scanCode)) {
            return inputAction();
        }
        if (class_3675.field_31950 == keyCode) {
            OVERWRITE_KEY_PRESSED = false;
            return true;
        }
        if (class_3675.field_31949 == keyCode) {
            DELETE_KEY_PRESSED = false;
            return true;
        }
        return false;
    }

    @Override
    public boolean method_25406(double mouseX, double mouseY, int button) {
        if (KeyRegistry.openProfilesScreenKey.method_1433(button)) {
            return inputAction();
        }
        return false;
    }

    private boolean inputAction() {
        int section = MouseLocation.getHoveredProfileSection(this.mouseX, this.mouseY);
        if (section != -1) {
            Profile profile = sections.get(section).getProfile();
            if (profile == null) {
                if (DELETE_KEY_PRESSED) {
                    if (field_22787 != null) field_22787.method_18858(() -> field_22787.method_1507(new ProfilesNamingScreen()));
                } else {
                    ProfileHandler.create("", ProfileHandler.getAvailableProfileKey());
                }
            } else if (DELETE_KEY_PRESSED) {
                ProfileHandler.delete(profile);
            } else if (OVERWRITE_KEY_PRESSED) {
                ProfileHandler.overwrite(profile);
            } else {
                ProfileHandler.load(profile);
            }
        }
        this.method_25419();
        return true;
    }
}

==> inventive-inventory-1.3.3-sources.jar: net/inventive_mods/inventive_inventory/features/profiles/gui/ProfilesScreen.java <==
package net.inventive_mods.inventive_inventory.features.profiles.gui;

import com.mojang.blaze3d.systems.RenderSystem;
import net.minecraft.class_10142;
import net.minecraft.class_1703;
import net.minecraft.class_2561;
import net.minecraft.class_286;
import net.minecraft.class_287;
import net.minecraft.class_289;
import net.minecraft.class_290;
import net.minecraft.class_293;
import net.minecraft.class_332;
import net.minecraft.class_3675;
import net.minecraft.class_465;
import net.minecraft.client.render.*;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.inventive_mods.inventive_inventory.features.profiles.Profile;
import net.inventive_mods.inventive_inventory.features.profiles.ProfileHandler;
import net.inventive_mods.inventive_inventory.features.profiles.gui.widgets.Section;
import net.inventive_mods.inventive_inventory.keys.KeyRegistry;
import net.inventive_mods.inventive_inventory.util.mouse.MouseLocation;

import java.util.ArrayList;
import java.util.List;

public class ProfilesScreen extends class_465<class_1703> {
    public static final int RADIUS = 60;
    public static final int COLOR = 0x7F000000;
    public static final int HOVER_COLOR = 0x3FFFFFFF;
    public static final int DELETE_COLOR = 0x7FE4080A;
    public static final int OVERWRITE_COLOR = 0x7FFFDE59;
    private static final List<Section> sections = new ArrayList<>();
    public static boolean DELETE_KEY_PRESSED;
    public static boolean OVERWRITE_KEY_PRESSED;
    private int mouseX;
    private int mouseY;

    public ProfilesScreen() {
        super(InventiveInventory.getScreenHandler(), InventiveInventory.getPlayer().method_31548(), class_2561.method_43470("Profile Screen"));
        if (this.field_22787 != null) this.field_22787.method_18502(null);
        sections.clear();
        for (Profile profile : ProfileHandler.getProfiles()) {
            if (sections.size() <= ProfileHandler.MAX_PROFILES) sections.add(new Section(sections.size(), profile));
        }
        if (sections.size() < ProfileHandler.MAX_PROFILES) sections.add(new Section(sections.size(), null));
        DELETE_KEY_PRESSED = false;
        OVERWRITE_KEY_PRESSED = false;
    }

    public static List<Section> getSections() {
        return sections;
    }

    @Override
    protected void method_2389(class_332 context, float delta, int mouseX, int mouseY) {
    }

    @Override
    public void method_25394(class_332 context, int mouseX, int mouseY, float delta) {
        this.mouseX = mouseX;
        this.mouseY = mouseY;

        RenderSystem.enableBlend();
        RenderSystem.setShader(class_10142.field_53876);
        RenderSystem.setShaderColor(1.0F, 1.0F, 1.0F, 1.0F);

        class_287 builder = class_289.method_1348().method_60827(class_293.class_5596.field_27382, class_290.field_1576);

        for (Section section : sections) {
            section.drawBackground(builder, section.isHovered(mouseX, mouseY));
        }
        class_286.method_43433(builder.method_60800());

        for (Section section : sections) {
            section.drawIcon(context);
            section.drawTooltips(context, mouseX, mouseY);
        }
        RenderSystem.disableBlend();
    }

    @Override
    public boolean method_25404(int keyCode, int scanCode, int modifiers) {
        if (class_3675.field_31949 == keyCode) {
            DELETE_KEY_PRESSED = true;
            return true;
        } else if (class_3675.field_31950 == keyCode) {
            OVERWRITE_KEY_PRESSED = true;
            return true;
        }
        return false;
    }

    @Override
    public boolean method_16803(int keyCode, int scanCode, int modifiers) {
        if (KeyRegistry.openProfilesScreenKey.method_1417(keyCode, scanCode)) {
            return inputAction();
        }
        if (class_3675.field_31950 == keyCode) {
            OVERWRITE_KEY_PRESSED = false;
            return true;
        }
        if (class_3675.field_31949 == keyCode) {
            DELETE_KEY_PRESSED = false;
            return true;
        }
        return false;
    }

    @Override
    public boolean method_25406(double mouseX, double mouseY, int button) {
        if (KeyRegistry.openProfilesScreenKey.method_1433(button)) {
            return inputAction();
        }
        return false;
    }

    private boolean inputAction() {
        int section = MouseLocation.getHoveredProfileSection(this.mouseX, this.mouseY);
        if (section != -1) {
            Profile profile = sections.get(section).getProfile();
            if (profile == null) {
                if (DELETE_KEY_PRESSED) {
                    if (field_22787 != null) field_22787.method_63588(() -> field_22787.method_1507(new ProfilesNamingScreen()));
                } else {
                    ProfileHandler.create("", ProfileHandler.getAvailableProfileKey());
                }
            } else if (DELETE_KEY_PRESSED) {
                ProfileHandler.delete(profile);
            } else if (OVERWRITE_KEY_PRESSED) {
                ProfileHandler.overwrite(profile);
            } else {
                ProfileHandler.load(profile);
            }
        }
        this.method_25419();
        return true;
    }
}
